@@ -188,12 +188,19 @@ class TamingDecoder(ImageGenerator):
 
     def get_latents_from_img(
         self,
-        img: PIL.Image.Image,
+        img: Union[torch.Tensor, PIL.Image.Image],
     ):
-        img = img.convert('RGB')
+        if torch.is_tensor(img):
+            img_tensor = img
+        else:
+            img = img.convert('RGB')
 
-        img_tensor = torch.tensor(np.asarray(img)).to(
-            self.device).float()[None, :]
+            img_tensor = torch.tensor(np.asarray(img))
+
+        if len(img_tensor.shape) <= 3:
+            img_tensor = img_tensor[None, ::]
+
+        img_tensor = img_tensor.float().to(self.device)
         img_tensor = (img_tensor / 255.) * 2 - 1
         img_tensor = img_tensor.permute(0, 3, 1, 2)
 
